pub async fn dispatch_menu_key<S: PlayConnection>(
client: &mut GameClient<S>,
key: UiKeyEvent,
) -> boolExpand description
Returns true if the key was consumed by a menu handler.
pub async fn dispatch_menu_key<S: PlayConnection>(
client: &mut GameClient<S>,
key: UiKeyEvent,
) -> boolReturns true if the key was consumed by a menu handler.